@@ -26,6 +26,7 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
+from __future__ import print_function
 from smartcard.scard import *
 
 try:
@@ -40,7 +41,7 @@ try:
         hresult, readers = SCardListReaders(hcontext, [])
         if hresult != SCARD_S_SUCCESS:
             raise error(
-                'Failed to list readers:: ' + \
+                'Failed to list readers: ' + \
                 SCardGetErrorMessage(hresult))
         print('PCSC Readers:', readers)
 
